from setuptools import setup, find_packages

setup(
    name="goldhandtest",
    version="1.0",
    author="Mihaly",
    author_email="ormraat.pte@gmail.com",
    description="A description of your package",
    license="MIT",
    install_requires=[],
    packages=find_packages(),
)
